#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .fps import fps
from .format_2 import format
from .quality_1 import quality
from .name_3 import name
from .use_original_resolution import use_original_resolution
from .scale_4 import scale
from .set_standard_resolution import set_standard_resolution
from .width_2 import width
from .height_2 import height
from .advance_quality import advance_quality
class video(Group):
    """
    'video' child.
    """

    fluent_name = "video"

    child_names = \
        ['fps', 'format', 'quality', 'name', 'use_original_resolution',
         'scale', 'set_standard_resolution', 'width', 'height',
         'advance_quality']

    fps: fps = fps
    """
    fps child of video.
    """
    format: format = format
    """
    format child of video.
    """
    quality: quality = quality
    """
    quality child of video.
    """
    name: name = name
    """
    name child of video.
    """
    use_original_resolution: use_original_resolution = use_original_resolution
    """
    use_original_resolution child of video.
    """
    scale: scale = scale
    """
    scale child of video.
    """
    set_standard_resolution: set_standard_resolution = set_standard_resolution
    """
    set_standard_resolution child of video.
    """
    width: width = width
    """
    width child of video.
    """
    height: height = height
    """
    height child of video.
    """
    advance_quality: advance_quality = advance_quality
    """
    advance_quality child of video.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .max_coarse_levels_2 import max_coarse_levels
from .coarsen_by_interval_2 import coarsen_by_interval
class coarsening_parameters(Group):
    """
    'coarsening_parameters' child.
    """

    fluent_name = "coarsening-parameters"

    child_names = \
        ['max_coarse_levels', 'coarsen_by_interval']

    max_coarse_levels: max_coarse_levels = max_coarse_levels
    """
    max_coarse_levels child of coarsening_parameters.
    """
    coarsen_by_interval: coarsen_by_interval = coarsen_by_interval
    """
    coarsen_by_interval child of coarsening_parameters.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .pattern import pattern
from .weight import weight
from .color import color
class lines_child(Group):
    """
    'child_object_type' of lines.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['pattern', 'weight', 'color']

    pattern: pattern = pattern
    """
    pattern child of lines_child.
    """
    weight: weight = weight
    """
    weight child of lines_child.
    """
    color: color = color
    """
    color child of lines_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .feature_angle import feature_angle
class feature(Group):
    """
    'feature' child.
    """

    fluent_name = "feature"

    child_names = \
        ['feature_angle']

    feature_angle: feature_angle = feature_angle
    """
    feature_angle child of feature.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .direction_0 import direction_0
from .direction_1 import direction_1
from .conductivity_0 import conductivity_0
from .conductivity_1 import conductivity_1
from .conductivity_2 import conductivity_2
class orthotropic(Group):
    """
    'orthotropic' child.
    """

    fluent_name = "orthotropic"

    child_names = \
        ['direction_0', 'direction_1', 'conductivity_0', 'conductivity_1',
         'conductivity_2']

    direction_0: direction_0 = direction_0
    """
    direction_0 child of orthotropic.
    """
    direction_1: direction_1 = direction_1
    """
    direction_1 child of orthotropic.
    """
    conductivity_0: conductivity_0 = conductivity_0
    """
    conductivity_0 child of orthotropic.
    """
    conductivity_1: conductivity_1 = conductivity_1
    """
    conductivity_1 child of orthotropic.
    """
    conductivity_2: conductivity_2 = conductivity_2
    """
    conductivity_2 child of orthotropic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .direction_0 import direction_0
from .direction_1 import direction_1
from .diffusivity_0 import diffusivity_0
from .diffusivity_1 import diffusivity_1
from .diffusivity_2 import diffusivity_2
class orthotropic(Group):
    """
    'orthotropic' child.
    """

    fluent_name = "orthotropic"

    child_names = \
        ['direction_0', 'direction_1', 'diffusivity_0', 'diffusivity_1',
         'diffusivity_2']

    direction_0: direction_0 = direction_0
    """
    direction_0 child of orthotropic.
    """
    direction_1: direction_1 = direction_1
    """
    direction_1 child of orthotropic.
    """
    diffusivity_0: diffusivity_0 = diffusivity_0
    """
    diffusivity_0 child of orthotropic.
    """
    diffusivity_1: diffusivity_1 = diffusivity_1
    """
    diffusivity_1 child of orthotropic.
    """
    diffusivity_2: diffusivity_2 = diffusivity_2
    """
    diffusivity_2 child of orthotropic.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .study_name import study_name
class set_as_current(Command):
    """
    Set As Current Study.
    
    Parameters
    ----------
        study_name : str
            'study_name' child.
    
    """

    fluent_name = "set-as-current"

    argument_names = \
        ['study_name']

    study_name: study_name = study_name
    """
    study_name argument of set_as_current.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .viscous_scale import viscous_scale
from .gravity_scale import gravity_scale
from .surface_tension_scale import surface_tension_scale
from .acoustic_scale import acoustic_scale
class time_scale_options(Group):
    """
    'time_scale_options' child.
    """

    fluent_name = "time-scale-options"

    child_names = \
        ['viscous_scale', 'gravity_scale', 'surface_tension_scale',
         'acoustic_scale']

    viscous_scale: viscous_scale = viscous_scale
    """
    viscous_scale child of time_scale_options.
    """
    gravity_scale: gravity_scale = gravity_scale
    """
    gravity_scale child of time_scale_options.
    """
    surface_tension_scale: surface_tension_scale = surface_tension_scale
    """
    surface_tension_scale child of time_scale_options.
    """
    acoustic_scale: acoustic_scale = acoustic_scale
    """
    acoustic_scale child of time_scale_options.
    """



"""Wrapper over the events gRPC service of Fluent."""

import grpc

from ansys.api.fluent.v0 import events_pb2 as EventsProtoModule
from ansys.api.fluent.v0 import events_pb2_grpc as EventsGrpcModule
from ansys.fluent.core.services.streaming import StreamingService


class EventsService(StreamingService):
    """Class wrapping the events gRPC service of Fluent."""

    def __init__(self, channel: grpc.Channel, metadata):
        super().__init__(
            stub=EventsGrpcModule.EventsStub(channel),
            request=EventsProtoModule.BeginStreamingRequest(),
            metadata=metadata,
        )



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .solver import solver
from .adjust_solver_defaults_based_on_setup import adjust_solver_defaults_based_on_setup
from .gravity import gravity
class general(Group):
    """
    'general' child.
    """

    fluent_name = "general"

    child_names = \
        ['solver', 'adjust_solver_defaults_based_on_setup', 'gravity']

    solver: solver = solver
    """
    solver child of general.
    """
    adjust_solver_defaults_based_on_setup: adjust_solver_defaults_based_on_setup = adjust_solver_defaults_based_on_setup
    """
    adjust_solver_defaults_based_on_setup child of general.
    """
    gravity: gravity = gravity
    """
    gravity child of general.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .application import application
from .border_3 import border
from .bottom_3 import bottom
from .clear_3 import clear
from .company import company
from .date import date
from .left_3 import left
from .right_4 import right
from .top_3 import top
from .visible_4 import visible
from .alignment import alignment
class text(Group):
    """
    Enter the text window options menu.
    """

    fluent_name = "text"

    child_names = \
        ['application', 'border', 'bottom', 'clear', 'company', 'date',
         'left', 'right', 'top', 'visible', 'alignment']

    application: application = application
    """
    application child of text.
    """
    border: border = border
    """
    border child of text.
    """
    bottom: bottom = bottom
    """
    bottom child of text.
    """
    clear: clear = clear
    """
    clear child of text.
    """
    company: company = company
    """
    company child of text.
    """
    date: date = date
    """
    date child of text.
    """
    left: left = left
    """
    left child of text.
    """
    right: right = right
    """
    right child of text.
    """
    top: top = top
    """
    top child of text.
    """
    visible: visible = visible
    """
    visible child of text.
    """
    alignment: alignment = alignment
    """
    alignment child of text.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from .include_convective_heat_transfer import include_convective_heat_transfer
from .include_lwf_particles_in_dpm_concentration import include_lwf_particles_in_dpm_concentration
from .wall_film_temperature_limiter import wall_film_temperature_limiter
class wall_film(Group):
    """
    'wall_film' child.
    """

    fluent_name = "wall-film"

    child_names = \
        ['include_convective_heat_transfer',
         'include_lwf_particles_in_dpm_concentration',
         'wall_film_temperature_limiter']

    include_convective_heat_transfer: include_convective_heat_transfer = include_convective_heat_transfer
    """
    include_convective_heat_transfer child of wall_film.
    """
    include_lwf_particles_in_dpm_concentration: include_lwf_particles_in_dpm_concentration = include_lwf_particles_in_dpm_concentration
    """
    include_lwf_particles_in_dpm_concentration child of wall_film.
    """
    wall_film_temperature_limiter: wall_film_temperature_limiter = wall_film_temperature_limiter
    """
    wall_film_temperature_limiter child of wall_film.
    """
